
###########################################################################
## Set the working directory

## In RStudio the working directory is easily set via the menu
## "Session -> Set Working Directory -> To Source File Location" 
## Note: In R only "/" is used for separating in paths 
## (i.e. no backslash).
setwd("Replace with path to directory containing project files.")


###########################################################################
## Read data into R

## Read data from soenderborg1_data.csv
D <- read.table("soenderborg1_data.csv", header=TRUE, sep=";", 
                as.is=TRUE)


###########################################################################
## Simple overview of the data

## Dimensions of D (number of rows and columns)
dim(D)
##  Column/variable names
names(D)
## The first rows/observations
head(D)
## The last rows/observations
tail(D)
## Selected summary statistics
summary(D)
## Another type of summary of the dataset
str(D)


###########################################################################
## Histogram (empirical density)

## Histogram describing the empirical density of the daily heat 
## consumptions of House 1 (histogram of daily consumptions normalized 
## to have an area of 1)
hist(D$Q1, xlab="Heat consumption (House 1)", prob=TRUE)


###########################################################################
## Conversion to a date variable

## Converts the variable 't' to a date variable in R
D$t <- as.Date(x=D$t, format="%Y-%m-%d")
## Checks the result
summary(D$t)


###########################################################################
## Plot of data over time

## Plot of heat consumption over time
plot(D$t, D$Q1, type="l", xlim=as.Date(c("2008-10-02","2010-10-01")), 
     ylim=c(0,9), xlab="Date", ylab="Heat consumption", col=2)
lines(D$t, D$Q2, col=3)
lines(D$t, D$Q3, col=4)
lines(D$t, D$Q4, col=5)
## Add a legend
legend("topright", legend=paste0("Q", c(1,2,3,4)), lty=1, col=2:5)


###########################################################################
## Taking a subset

## Subset of the data: only Jan-Feb 2010
Dsel <- subset(D, "2010-01-01" <= t & t < "2010-3-01")


###########################################################################
## Box plot

## Box plot of daily heat consumption by house
boxplot(Dsel[ ,c("Q1","Q2","Q3","Q4")],
        xlab="House", ylab="Heat consumption")


###########################################################################
## Summary statistics for daily heat consumptions

## Total number of observations for House 1 during Jan-Feb 2010
## (doesn't include missing values if there are any)
sum(!is.na(Dsel$Q1))
## Sample mean of daily heat consumption for House 1, Jan-Feb 2010
mean(Dsel$Q1, na.rm=TRUE)
## Sample variance of daily heat consumption for House 1, Jan-Feb 2010
var(Dsel$Q1, na.rm=TRUE)
## etc.
##
## The argument 'na.rm=TRUE' ensures that the statistic is
## computed even in cases where there are missing values.


###########################################################################
## qq-plot for model validation

## qq-plot of daily heat consumption (House 1)
qqnorm(Dsel$Q1)
qqline(Dsel$Q1)


###########################################################################
## Confidence interval for the mean

## CI for the mean daily heat consumption of House 1
t.test(Dsel$Q1, conf.level=0.95)$conf.int


###########################################################################
## One-sample t-test

##  Testing hypothesis mu=2.38 for daily heat consumption 
## (House 1, Jan-Feb 2010)
t.test(Dsel$Q1, mu=2.38)


###########################################################################
## Welch t-test for comparing two (independent) samples

## Comparing the heat consumption of House 1 and 2
t.test(Dsel$Q1, Dsel$Q2)


###########################################################################
## Computing correlations

## Correlation between heat consumption and global radiation
cor(D[, c("Q1","G")], use="pairwise.complete.obs")


###########################################################################
## Subsets in R

## Optional extra remark about taking subsets in R
##
## A logical vector with TRUE or FALSE for each row in D, e.g.:
## Finding days with frost
D$Ta < 0
## Can be used to extract heat consumptions for House 1 on 
## days with frost
D$Q1[D$Ta < 0]
## The 'subset' function can be used as well
subset(D, Ta < 0)
## More complex logical expressions can be made, e.g.:
## Observations from days with frost before 2010
subset(D, t < "2010-01-01" & Ta < 0)


###########################################################################
## More R tips

## Use a 'for'-loop to calculate the summary statistics for each house
## and assign the result to a new data.frame
Tbl <- data.frame()
## Find the relevant columns
selected <- c("Q1","Q2","Q3","Q4")
## Calculate the summary statistics for each house
for(i in selected){
  ## Take the relevant column
  x <- Dsel[, i]
  ## Compute the sample mean
  Tbl[i, "mean"] <- mean(x, na.rm=TRUE)
  ## Compute the sample variance
  Tbl[i, "var"] <- var(x, na.rm=TRUE) }
## View the content of Tbl
Tbl
  
## In R there are even more condensed ways to do such 
## calculations, e.g.:
apply(Dsel[, selected], 2, mean, na.rm=TRUE)
## or several calculations in one go
apply(Dsel[, selected], 2, function(x){
  c(mean=mean(x, na.rm=TRUE),
    var=var(x, na.rm=TRUE)) })
## See more useful functions with: ?apply, ?aggregate and ?lapply
## For extremely efficient data handling see, e.g., the packages: 
## dplyr, tidyr, reshape2 and ggplot2

## LaTeX tips:
## The R package "xtable" can generate LaTeX tables written to a file 
## and thereby they can automatically be included in a .tex document.
## The R package "knitr" can be used very elegantly to generate .tex 
## documents with R code written directly in the document. This  
## document and the book were generated using knitr.
